@@ -28,5 +28,5 @@ class NestedClient(Client):
         self.parent = parent
 
     @classmethod
-    def as_property(cls) -> 'NestedClient':
-        return cached_property(lambda self: cls(parent=self, **self.kw))
+    def as_property(cls, **kw) -> 'NestedClient':
+        return cached_property(lambda self: cls(parent=self, **{**self.kw, **kw}))
